@@ -2,11 +2,11 @@
 #######################################################################
 """Article class for the Zope 3 based ng.content.article package
 
-$Id: article.py 49881 2008-02-02 14:37:04Z cray $
+$Id: article.py 50804 2008-02-21 11:34:40Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49881 $"
+__version__ = "$Revision: 50804 $"
  
 from zope.interface import implements
 
@@ -15,6 +15,7 @@ from ks.smartimage.smartimage import SmartImage
 from ng.content.article.interfaces import IDocShort,IDocFormatSwitcher
 from interfaces import IArticleContainerOrdered,IArticleContained,IArticle
 import datetime
+import pytz 
 
 class ArticleBase(OrderedContainer):
     __doc__ = IArticle.__doc__
@@ -25,11 +26,11 @@ class ArticleBase(OrderedContainer):
         #self.logo = SmartImage()
         #self.logo.__parent__ = self
         #self.logo.__name__ = "logo"
-        self.created = datetime.datetime.now()        
+        self.created = datetime.datetime.now(pytz.utc)        
         
     title = u""
     abstract = u""
-    created = datetime.datetime.now()
+    created = datetime.datetime.now(pytz.utc)        
     author = u""
     iscontent = False
     isdivision = False
