@@ -1,25 +1,31 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Maincontainer class for the Zope 3 based maincontainer package
+"""MainContainer class for the Zope 3 based
+ng.content.article.maincontainer package
 
-$Id: maincontainer.py 49881 2008-02-02 14:37:04Z cray $
+$Id: maincontainer.py 50804 2008-02-21 11:34:40Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49881 $"
+__version__ = "$Revision: 50804 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
 from zope.app.component.site import SiteManagerContainer
 from zope.app.container.ordered import OrderedContainer
 from interfaces import IMainContainerOrdered, IMainContained, IUrlPage, IMainPage
+import datetime,pytz
 
 class MainContainer(OrderedContainer, SiteManagerContainer) :
-    """ Basic container for future CMS
+    """ Basic container for some storages
     """
-
     implements(IMainContainerOrdered, IMainContained, IUrlPage, IMainPage)
 
+    def __init__(self,*kv,**kw) :
+        super(MainContainer,self).__init__(*kv,**kw)
+        self.created = datetime.datetime.now(pytz.utc)        
+
+
     urls = ()
 
     mainiface = None
@@ -30,5 +36,5 @@ class MainContainer(OrderedContainer, SiteManagerContainer) :
     
     author = u""
     
-    created = None
+    created = datetime.datetime.now(pytz.utc)
     
\ No newline at end of file
